@@ -33,11 +33,17 @@ sub get_foreign_keys{
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-FabForce::DBDesigner4::SQL::Utils - some utility functions for SQL generation
+FabForce::DBDesigner4::SQL::Utils
+
+=head1 VERSION
+
+version 0.307
 
 =head1 SYNOPSIS
 
@@ -48,6 +54,10 @@ FabForce::DBDesigner4::SQL::Utils - some utility functions for SQL generation
 As each database system has its own syntax, it is important to provide functions
 for each system.
 
+=head1 NAME
+
+FabForce::DBDesigner4::SQL::Utils - some utility functions for SQL generation
+
 =head1 METHODS
 
 =head2 get_foreign_keys
@@ -63,4 +73,22 @@ Copyright (C) 2005 - 2009 by Renee Baecker
 This program is free software; you can redistribute it and/or
 modify it under the terms of the Artistic License version 2.0.
 
-=cut
\ No newline at end of file
+=cut
+
+=head1 AUTHOR
+
+Renee Baecker <module@renee-baecker.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Renee Baecker.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
+=cut
+
+
+__END__
+
